@@ -200,10 +200,12 @@ def run(actions, debug):
 
         for action in actions:
             click.echo("performing " + str(action.vac_command))
-
-            while True:
-                vacbot.request_all_statuses()
-                time.sleep(20)
+            vacbot.request_all_statuses()
+            vacbot.refresh_liveMap()
+            _LOGGER.debug("Vacuum Status: {}".format(vacbot.vacuum_status))
+            _LOGGER.debug("Fan Speed: {}".format(vacbot.fan_speed))
+            _LOGGER.debug("Image Url: {}".format(vacbot.last_clean_image))
+            _LOGGER.debug("Live Map: {}".format(vacbot.live_map))
 		
         for v in vacbot.rooms:
             _LOGGER.debug(v)
