@@ -245,6 +245,9 @@ class EcoVacsIOTMQ(ClientMQTT):
                 jsonstring['event'] = "map_sub_set"
             elif 'getwater' in eventname:
                 jsonstring['event'] = "water_info"
+            elif 'setspeed' in eventname:
+                # Ignore, no need to handle
+                return
             else:
                 _LOGGER.warning("Event Not Found " + str(eventname))
                 return
