@@ -70,6 +70,8 @@ class Map:
             im = Image.new("RGBA", (6400, 6400))
             draw = ImageDraw.Draw(im)
 
+            _LOGGER.debug("GetBase64Map finish initializing")
+
             imageX = 0
             imageY = 0
 
@@ -88,24 +90,56 @@ class Map:
                         if self.buffer[i][x][y] == 0x02: #wall
                             draw.point((imageX+x,imageY+y), fill=(78,150,226))
 
+            _LOGGER.debug("GetBase64Map finish drawing")
+            
             del draw
 
             #Flip
             im = ImageOps.flip(im)
+            _LOGGER.debug("GetBase64Map finish flip")
 
             #Crop
             image_data = np.asarray(im)
+            _LOGGER.debug("image_data = np.asarray(im)")
+            del im
+            _LOGGER.debug("del im")
+
             image_data_bw = image_data.max(axis=2)
+            _LOGGER.debug("image_data_bw = image_data.max(axis=2)")
+
             non_empty_columns = np.where(image_data_bw.max(axis=0)>0)[0]
+            _LOGGER.debug("non_empty_columns = np.where(image_data_bw.max(axis=0)>0)[0]")
+
             non_empty_rows = np.where(image_data_bw.max(axis=1)>0)[0]
+            _LOGGER.debug("non_empty_rows = np.where(image_data_bw.max(axis=1)>0)[0]")
+
             cropBox = (min(non_empty_rows), max(non_empty_rows), min(non_empty_columns), max(non_empty_columns))
+            _LOGGER.debug("cropBox = (min(non_empty_rows), max(non_empty_rows), min(non_empty_columns), max(non_empty_columns))")
 
             image_data_new = image_data[cropBox[0]:cropBox[1]+1, cropBox[2]:cropBox[3]+1 , :]
+            _LOGGER.debug("image_data_new = image_data[cropBox[0]:cropBox[1]+1, cropBox[2]:cropBox[3]+1 , :]")
+
+            del image_data
+            _LOGGER.debug("del image_data")
 
             new_image = Image.fromarray(image_data_new)
+            _LOGGER.debug("new_image = Image.fromarray(image_data_new)")
+
+            del image_data_new
+            _LOGGER.debug("del image_data_new")
 
             buffered = BytesIO()
+            _LOGGER.debug("buffered = BytesIO()")
+
+            _LOGGER.debug("GetBase64Map finish crop")
+
             new_image.save(buffered, format="PNG")
+            _LOGGER.debug("new_image.save(buffered, format=PNG)")
+
+            del new_image
+            _LOGGER.debug("del new_image")
+
+            _LOGGER.debug("GetBase64Map finish saving")
 
             self.isMapUpdated = True
 
